@@ -8,7 +8,6 @@ from typing import Any, Dict, Generic, Hashable, Optional, Tuple, Type, Union
 
 from omnipy.compute.job_types import JobBaseT, JobT, JobTemplateT
 from omnipy.compute.mixins.name import NameJobBaseMixin, NameJobMixin
-from omnipy.config.job import JobConfig
 from omnipy.engine.protocols import IsJob, IsJobConfig, IsJobCreator, IsTaskRunnerEngine
 from omnipy.util.helpers import create_merged_dict
 from omnipy.util.mixin import DynamicMixinAcceptor, DynamicMixinAcceptorFactory
@@ -19,7 +18,7 @@ class JobCreator:
         self._engine: Optional[IsTaskRunnerEngine] = None
         self._config: Optional[IsJobConfig] = None
         self._nested_context_level: int = 0
-        self._datetime_of_nested_context_run: Optional[datetime] = None
+        self._time_of_cur_toplevel_nested_context_run: Optional[datetime] = None
 
     def set_engine(self, engine: IsTaskRunnerEngine) -> None:
         self._engine = engine
@@ -29,7 +28,7 @@ class JobCreator:
 
     def __enter__(self):
         if self._nested_context_level == 0:
-            self._datetime_of_nested_context_run = datetime.now()
+            self._time_of_cur_toplevel_nested_context_run = datetime.now()
 
         self._nested_context_level += 1
 
@@ -37,7 +36,7 @@ class JobCreator:
         self._nested_context_level -= 1
 
         if self._nested_context_level == 0:
-            self._datetime_of_nested_context_run = None
+            self._time_of_cur_toplevel_nested_context_run = None
 
     @property
     def engine(self) -> Optional[IsTaskRunnerEngine]:
@@ -52,11 +51,8 @@ class JobCreator:
         return self._nested_context_level
 
     @property
-    def datetime_of_nested_context_run(self) -> datetime:
-        return self._datetime_of_nested_context_run
-
-
-# TODO: test datetime_of_nested_context_run
+    def time_of_cur_toplevel_nested_context_run(self) -> datetime:
+        return self._time_of_cur_toplevel_nested_context_run
 
 
 class JobBaseMeta(ABCMeta):
@@ -91,7 +87,7 @@ class JobTemplateAndMixinAcceptorMeta(JobTemplateMeta, JobBaseAndMixinAcceptorMe
 
 class JobBase(DynamicMixinAcceptor, metaclass=JobBaseAndMixinAcceptorMeta):
     def __init__(self, *args: object, name: Optional[str] = None, **kwargs: object):
-        super().__init__(*args, **kwargs)
+        super().__init__()
 
         if not isinstance(self, JobTemplate) and not isinstance(self, Job):
             raise RuntimeError('JobBase and subclasses not inheriting from JobTemplate '
@@ -126,7 +122,7 @@ class JobBase(DynamicMixinAcceptor, metaclass=JobBaseAndMixinAcceptorMeta):
 
         return {key: getattr(self, key) for key in kwarg_keys}
 
-    def __eq__(self, other: object):
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, JobBase):
             return NotImplemented
         return self._get_init_args() == other._get_init_args() \
@@ -162,7 +158,7 @@ class JobTemplate(JobBase, Generic[JobT], metaclass=JobTemplateAndMixinAcceptorM
     def create(cls: Type[JobTemplateT], *init_args: object, **init_kwargs: object) -> JobTemplateT:
         return cls(*init_args, **init_kwargs)
 
-    def run(self, *args: object, **kwargs: object):
+    def run(self, *args: object, **kwargs: object) -> object:
         return self.apply()(*args, **kwargs)
 
     def apply(self) -> JobT:
@@ -203,12 +199,8 @@ class CallableDecoratingJobTemplateMixin:
 
 class Job(JobBase, DynamicMixinAcceptor, Generic[JobBaseT, JobTemplateT]):
     @property
-    def flow_context(self) -> IsJobCreator:
-        return self.__class__.job_creator
-
-    @property
-    def datetime_of_flow_run(self) -> datetime:
-        return self.__class__.job_creator.datetime_of_nested_context_run
+    def time_of_cur_toplevel_flow_run(self) -> datetime:
+        return self.__class__.job_creator.time_of_cur_toplevel_nested_context_run
 
     @classmethod
     @abstractmethod
@@ -248,10 +240,6 @@ class Job(JobBase, DynamicMixinAcceptor, Generic[JobBaseT, JobTemplateT]):
     def __call__(self, *args: Any, **kwargs: Any) -> Any:
         ...
 
-    @abstractmethod
-    def _call_func(self, *args: Any, **kwargs: Any) -> Any:
-        ...
-
 
 Job.accept_mixin(NameJobMixin)
 
