@@ -66,7 +66,7 @@ class SerializerFuncJobBaseMixin:
             return self._persist_outputs if self._persist_outputs is not None \
                     else PersistOpts.DISABLED
         else:
-            from omnipy.compute.private.flow import FlowBase
+            from omnipy.compute.flow import FlowBase
             from omnipy.compute.task import TaskBase
 
             config_persist_opt = self.config.persist_outputs
@@ -130,16 +130,16 @@ class SerializerFuncJobMixin:
         return results
 
     def _serialize_and_persist_outputs(self, results: Dataset):
-        run_time = self.datetime_of_flow_run if self.datetime_of_flow_run is not None \
-            else datetime.now()
-        datetime_str = run_time.strftime('%Y_%m_%d-%H_%M_%S')
+        datetime_str = self._generate_datetime_str()
         output_path = Path(self.config.persist_data_dir_path).joinpath(datetime_str)
 
         if not os.path.exists(output_path):
             os.makedirs(output_path)
 
         num_cur_files = len(os.listdir(output_path))
-        file_path = output_path.joinpath(f'{num_cur_files:02}-{self.name}.tar.gz')
+        job_name = self._create_job_name()
+
+        file_path = output_path.joinpath(f'{num_cur_files:02}_{job_name}.tar.gz')
 
         parsed_dataset, serializer = \
             self._serializer_registry.auto_detect_tar_file_serializer(results)
@@ -149,6 +149,20 @@ class SerializerFuncJobMixin:
         with open(file_path, 'wb') as tarfile:
             tarfile.write(serializer.serialize(parsed_dataset))
 
+    def _create_job_name(self):
+        return '_'.join(self.unique_name.split('-')[:-2])
+
+    def _generate_datetime_str(self):
+        if self.time_of_cur_toplevel_flow_run:
+            run_time = self.time_of_cur_toplevel_flow_run
+        else:
+            if hasattr(self, 'time_of_last_run'):
+                run_time = self.time_of_last_run
+            else:
+                run_time = datetime.now()
+        datetime_str = run_time.strftime('%Y_%m_%d-%H_%M_%S')
+        return datetime_str
+
     # TODO: Refactor
     def _deserialize_and_restore_outputs(self) -> Dataset:
         output_path = Path(self.config.persist_data_dir_path)
@@ -159,7 +173,7 @@ class SerializerFuncJobMixin:
                 last_dir_path = output_path.joinpath(last_dir)
                 for job_output_name in reversed(sorted(os.listdir(last_dir_path))):
                     name_part_of_filename = job_output_name[3:-7]
-                    if name_part_of_filename == self.name:
+                    if name_part_of_filename == self._create_job_name():
                         tar_file_path = last_dir_path.joinpath(job_output_name)
                         with tarfile.open(tar_file_path, 'r:gz') as tarfile_obj:
                             file_suffixes = set(fn.split('.')[-1] for fn in tarfile_obj.getnames())
